==> ripe-atlas-tools_1.2.2.orig.tar.gz: ripe-atlas-tools-1.2.2/PACKAGING.md <==
We're working with the community to get this project packaged for as many
platforms as possible.  To that end, We've created this file to help organise
resources.

If you'd like to package the toolkit for your favourite distro, or if you've
already started, please add your name/GitHub below with a pull request so we
don't have people wasting time doubling up on work rather than collaborating.


## OpenBSD

* [Florian Obser](https://github.com/fobser)

### Status

During the Bucharest hackathon, Florian hacked out a package it's already
[in the ports tree](http://cvsweb.openbsd.org/cgi-bin/cvsweb/ports/net/py-ripe.atlas.tools/).


## FreeBSD

* [Max Stucchi](https://github.com/stucchimax)

### Status

Max has submitted the new ports and [they have been accepted](https://svnweb.freebsd.org/ports?view=revision&revision=403526).


## Gentoo

* [Daniel Quinn](https://github.com/danielquinn)

### Status

After a great deal of help from #gentoo-proxy-maint, Daniel's pull requests were accepted into the Gentoo portage tree.  You can now install it with `emerge ripe-atlas-tools`.


## Debian

* Apollon Oikonomopoulos

### Status

Apollon is working with the RIPE Atlas team to ensure that the package conforms
to Debian standards and has volunteered to submit everything once it's ready.


## Arch

* [Wouter de Vries](https://github.com/woutifier)

### Status

Wouter has added this project to [Arch's AUR repository](https://aur.archlinux.org/packages/ripe-atlas-tools).

## Fedora 

* * [Jan Včelák](https://github.com/vcelda)

### Status 

In progress: https://github.com/fcelda/fedora-ripe-atlas-tools

Jan is currently building the binary packages in COPR (which will take some time as there is a lot of other packages in the queue):
https://copr.fedoraproject.org/coprs/jvcelak/ripe-atlas-tools/

## Other Platforms

We've been talking with members of the community about expanding the package
support for Magellan, but so far no one has officially volunteered. The RIPE
Atlas team is happy to assist anyone interested in porting this toolkit to any
platform, but we're especially keen on at least getting into:

* Ubuntu
* Red Hat
* CentOS

If you'd like to try your hand, or would simply like to offer some advice, feel
free to add your name here or contact us directly via *atlas at ripe dot net*.

==> ripe-atlas-tools_2.0.2.orig.tar.gz: ripe-atlas-tools-2.0.2/PACKAGING.md <==
We're working with the community to get this project packaged for as many
platforms as possible.  To that end, We've created this file to help organise
resources.

If you'd like to package the toolkit for your favourite distro, or if you've
already started, please add your name/GitHub below with a pull request so we
don't have people wasting time doubling up on work rather than collaborating.


## OpenBSD

* [Florian Obser](https://github.com/fobser)

### Status

During the Bucharest hackathon, Florian hacked out a package it's already
[in the ports tree](http://cvsweb.openbsd.org/cgi-bin/cvsweb/ports/net/py-ripe.atlas.tools/).


## FreeBSD

* [Max Stucchi](https://github.com/stucchimax)

### Status

Max has submitted the new ports and [they have been accepted](https://svnweb.freebsd.org/ports?view=revision&revision=403526).


## Gentoo

* [Daniel Quinn](https://github.com/danielquinn)

### Status

After a great deal of help from #gentoo-proxy-maint, Daniel's pull requests were accepted into the Gentoo portage tree.  You can now install it with `emerge ripe-atlas-tools`.


## Debian

* Apollon Oikonomopoulos

### Status

Apollon has imported the project to [debian tree](https://tracker.debian.org/pkg/ripe-atlas-tools).

## Ubuntu

### Status

Apollon's work in debian has made it also to Ubuntu.

## Arch

* [Wouter de Vries](https://github.com/woutifier)

### Status

Wouter has added this project to [Arch's AUR repository](https://aur.archlinux.org/packages/ripe-atlas-tools).

## Fedora 

* [Jan Včelák](https://github.com/vcelda)

### Status 

In progress: https://github.com/fcelda/fedora-ripe-atlas-tools

Jan is currently building the binary packages in COPR (which will take some time as there is a lot of other packages in the queue):
https://copr.fedoraproject.org/coprs/jvcelak/ripe-atlas-tools/

## Windows

* [Chris Amin](https://github.com/chrisamin)

### Status

A highly experimental self-contained installer is available at https://github.com/chrisamin/ripe-atlas-tools-win32/. This installer doesn't require the presence of a system Python installation.

## Other Platforms

We've been talking with members of the community about expanding the package
support for Magellan, but so far no one has officially volunteered. The RIPE
Atlas team is happy to assist anyone interested in porting this toolkit to any
platform, but we're especially keen on at least getting into:

* Red Hat
* CentOS

If you'd like to try your hand, or would simply like to offer some advice, feel
free to add your name here or contact us directly via *atlas at ripe dot net*.
